@@ -21,12 +21,18 @@ class NetworkPollerGrpcClient:
     MAX_MESSAGE_QLEN = 4000  # max number of messages we will queue
     POST_TIMEOUT = 30  # timeout post request after waiting 30s
 
-    def __init__(self, api_key=None, host=None, port=None, compression=False):
+    def __init__(self,
+                 api_key=None,
+                 host=None,
+                 port=None,
+                 compression=False,
+                 insecure=None):
         if host:
             self._client = PreseemGrpcClient(api_key=api_key,
                                              host=host,
                                              port=port,
-                                             compression=compression)
+                                             compression=compression,
+                                             insecure=insecure)
         else:
             self._client = None  # for testing
         self.host = host
